@@ -35,7 +35,8 @@ def configure():
             cbc_compiled_with_asl = False
         else:
             cbc_exec = CBC().executable()
-            results = pyutilib.subprocess.run(cbc_exec+" dummy -AMPL")
+            results = pyutilib.subprocess.run(
+                [cbc_exec,"dummy","-AMPL","-stop"] )
             if cbc_compiled_with_asl is not None:
                 raise IOError
             cbc_compiled_with_asl = not ('No match for AMPL' in results[1])
@@ -175,42 +176,62 @@ class CBCSHELL(SystemCallSolver):
         # the solution file (solutions!)
         self.results_file = self.soln_file
 
+        def _check_and_escape_options(options):
+            for key, val in self.options.iteritems():
+                tmp_k = str(key)
+                _bad = ' ' in tmp_k
+
+                tmp_v = str(val)
+                if ' ' in tmp_v:
+                    if '"' in tmp_v:
+                        if "'" in tmp_v:
+                            _bad = True
+                        else:
+                            tmp_v = "'" + tmp_v + "'"
+                    else:
+                        tmp_v = '"' + tmp_v + '"'
+
+                if _bad:
+                    raise ValueError("Unable to properly escape solver option:"
+                                     "\n\t%s=%s" % (key, val) )
+                yield (tmp_k, tmp_v)
+
         #
         # Define command line
         #
+        cmd = [ executable ]
+        if self._timer:
+            cmd.append(self._timer)
+
         if self._problem_format == ProblemFormat.nl:
+            cmd.append(problem_files[0])
+            cmd.append('-AMPL')
+
+            opts = ["stat=1", "printingOptions=all"]
             if self._timelimit is not None and self._timelimit > 0.0:
-                timing = " sec="+str(self._timelimit)
-            else:
-                timing = ""
-            opt = " log=5"
-            #if "debug" in self.options:
-                #opt = " log=5"
-            #else:
-                #opt = ""
-            for key in self.options:
-                if isinstance(self.options[key],basestring) and ' ' in self.options[key]:
-                    opt += " "+key+"=\""+str(self.options[key])+"\""
-                else:
-                    opt += " "+key+"="+str(self.options[key])
-            self._nl_options = " ".join(self.options) + timing+ " stat=1 "+opt+" printingOptions=all"
-            proc = self._timer + " " + executable + " " + problem_files[0] + " -AMPL "+self._nl_options
+                opts.append("sec=%s" % (self._timelimit,))
+            if "debug" in self.options:
+                opts.append("log=5")
+            for key, val in _check_and_escape_options(self.options):
+                opts.append("%s=%s" % ( key, tmp ))
+
+            env["CBC_options"] = " ".join(opts)            
+
         else:
             if self._timelimit is not None and self._timelimit > 0.0:
-                timing = " -sec "+str(self._timelimit)+" "
-            else:
-                timing = ""
+                cmd.extend(['-sec', str(self._timelimit)])
             if "debug" in self.options:
-                opt = " -log 5"
-            else:
-                opt = ""
-            for key in self.options:
-                if isinstance(self.options[key],basestring) and ' ' in self.options[key]:
-                    opt += " -"+key+" \""+str(self.options[key])+"\""
-                else:
-                    opt += " -"+key+" "+str(self.options[key])
-            proc = self._timer + " " + executable + opt + " -printingOptions all "+timing+ " -import "+problem_files[0]+ " -import -stat 1 -solve -solu " + self.soln_file
-        return pyutilib.misc.Bunch(cmd=proc, log_file=self.log_file, env=None)
+                cmd.extend(["-log","5"])
+            for key, val in _check_and_escape_options(self.options):
+                cmd.extend(['-'+key, tmp])
+            cmd.extend(["-printingOptions", "all",
+                        "-import", problem_files[0],
+                        "-import",
+                        "-stat", "1",
+                        "-solve", 
+                        "-solu", self.soln_file])
+
+        return pyutilib.misc.Bunch(cmd=cmd, log_file=self.log_file, env=None)
 
     def process_logfile(self):
         """
@@ -378,7 +399,6 @@ class CBCSHELL(SystemCallSolver):
                 results.solver.termination_condition = TerminationCondition.unbounded
                 solution.gap = None
                 results.solution.delete(0)
-                print "HERE", len(results.solution)
                 INPUT.close()
                 return
 
@@ -404,12 +424,26 @@ class CBCSHELL(SystemCallSolver):
                     raise RuntimeError, "CBC plugin encountered unexpected line=("+line.strip()+") in solution file="+self.soln_file+"; constraint and variable sections already processed!"
 
             if (processing_constraints is True) and (extract_duals is True):
+                if len(tokens) == 4:
+                    pass
+                elif (len(tokens) == 5) and tokens[0] == "**":
+                    tokens = tokens[1:]
+                else:
+                    raise RuntimeError, "Unexpected line format encountered in CBC solution file - line="+line
+
                 constraint = tokens[1]
                 constraint_ax = eval(tokens[2]) # CBC reports the constraint row times the solution vector - not the slack.
                 constraint_dual = eval(tokens[3])
                 solution.constraint[constraint].dual = constraint_dual
 
             elif processing_constraints is False:
+                if len(tokens) == 4:
+                    pass
+                elif (len(tokens) == 5) and tokens[0] == "**":
+                    tokens = tokens[1:]
+                else:
+                    raise RuntimeError, "Unexpected line format encountered in CBC solution file - line="+line
+
                 variable_name = tokens[1]
                 variable_value = eval(tokens[2])
                 variable = solution.variable[variable_name] = {"Value" : variable_value, "Id" : len(solution.variable)}
