@@ -144,7 +144,6 @@ class CPLEXDirect(OptSolver):
     #
     def _evaluate_bound(self, exp):
 
-        from coopr.pyomo.expr import is_constant
         from coopr.pyomo.base import expr
 
         if isinstance(exp, expr._IdentityExpression):
@@ -232,8 +231,8 @@ class CPLEXDirect(OptSolver):
         self._symbol_map = SymbolMap(pyomo_instance)
 
         from coopr.pyomo.base import Var, VarStatus, Objective, Constraint, IntegerSet, BooleanSet, SOSConstraint
-        from coopr.pyomo.base.numtypes import minimize, maximize
-        from coopr.pyomo.expr import is_constant
+        from coopr.pyomo.base.objective import minimize, maximize
+        from coopr.pyomo.expr import canonical_is_constant
 
         # TBD
         quadratic = False
@@ -314,7 +313,7 @@ class CPLEXDirect(OptSolver):
                     # requires a variable in the constraint body.  It is also
                     # possible that the body of the constraint consists of only a
                     # constant, in which case the "variable" of
-                    if is_constant(con.repn):
+                    if canonical_is_constant(con.repn):
                         continue
 
                     name=self._symbol_map.getSymbol(con,labeler)
@@ -456,11 +455,11 @@ class CPLEXDirect(OptSolver):
 
         cplex_instance.objective.set_name(the_objective.name)
 
-        self._symbol_map.getSymbol(the_objective, labeler)
-        self._symbol_map.alias(the_objective,'__default_objective__')
+        self._symbol_map.getSymbol(the_objective[None], labeler)
+        self._symbol_map.alias(the_objective[None],'__default_objective__')
 
 
-        if is_constant(the_objective[None].repn):
+        if canonical_is_constant(the_objective[None].repn):
             print ("Warning: Constant objective detected, replacing " + \
                     "with a placeholder to prevent solver failure.")
 
@@ -659,7 +658,6 @@ class CPLEXDirect(OptSolver):
         soln_type = instance.solution.get_solution_type()
         if soln_type > 0:
             soln.objective['__default_objective__'].value = instance.solution.get_objective_value()
-
             num_variables = instance.variables.get_num()
             variable_names = instance.variables.get_names()
             variable_values = instance.solution.get_values()
