@@ -146,7 +146,7 @@ class gurobi_direct ( OptSolver ):
     def _populate_gurobi_instance ( self, model ):
 
         from coopr.pyomo.base import Var, VarStatus, Objective, Constraint, IntegerSet, BooleanSet, SOSConstraint
-        from coopr.pyomo.expr import is_constant
+        from coopr.pyomo.expr import canonical_is_constant
 
         try:
             grbmodel = Model( name=model.name )
@@ -200,7 +200,7 @@ class gurobi_direct ( OptSolver ):
 
         for key in objective:
             expression = objective[ key ].repn
-            if is_constant( expression ):
+            if canonical_is_constant( expression ):
                 msg = "Ignoring objective '%s[%s]' which is constant"
                 logger.warning( msg % (str(objective), str(key)) )
                 continue
