@@ -13,7 +13,7 @@ currdir = dirname(abspath(__file__))+os.sep
 import unittest
 from nose.tools import nottest
 import coopr.opt
-import coopr.plugins.mip
+import coopr.plugins.solvers
 import coopr
 import pyutilib.services
 import pyutilib.component.core
@@ -79,9 +79,9 @@ class OptFactoryDebug(unittest.TestCase):
         ans = coopr.opt.SolverFactory("none")
         self.assertEqual(ans, None)
         ans = coopr.opt.SolverFactory("_mock_pico")
-        self.assertEqual(type(ans), coopr.plugins.mip.MockPICO)
+        self.assertEqual(type(ans), coopr.plugins.solvers.MockPICO)
         ans = coopr.opt.SolverFactory("_mock_pico", name="mymock")
-        self.assertEqual(type(ans), coopr.plugins.mip.MockPICO)
+        self.assertEqual(type(ans), coopr.plugins.solvers.MockPICO)
         self.assertEqual(ans.name,  "mymock")
 
     def test_solver_registration(self):
@@ -129,7 +129,7 @@ class OptFactoryDebug(unittest.TestCase):
         """
         ans = coopr.opt.ReaderFactory.services()
         #self.assertEqual(len(ans),4)
-        self.assertTrue(set(ans) >= set(["rtest3", "sol","yaml"]))
+        self.assertTrue(set(ans) >= set(["rtest3", "sol","yaml", "json"]))
 
     def test_reader_instance(self):
         """
